@@ -8,6 +8,7 @@ import inspect
 import json
 import time
 from datetime import datetime
+from decimal import Decimal
 from typing import Optional, Awaitable, Any
 
 from bson import ObjectId
@@ -43,71 +44,7 @@ class BaseHandler(RequestHandler):
         重写父类get请求处理方法，直接调用post方法统一处理
         :return:
         """
-        # 通过url路径获取对应的处理方法
-        res = [item for item in RouterMapping.instance().handlerMapping
-               if item[0] == self.request.path]
-        if res:
-            # 元组中索引0 存放url，索引 1 存放处理方法对象，此处获取方法对象
-            handler_method = res[0][1]
-            # 最终整理后的请求参数集合
-            params_list = []
-            # 当前请求参数
-            arguments = self.request.arguments
-            # 获取处理方法的 参数签名
-            signature = inspect.signature(handler_method)
-            # parameterName 参数名称, parameter 参数对象
-            for parameter_name, parameter in signature.parameters.items():
-                # 如果参数是self 做特殊处理，传入本身
-                if parameter_name == 'self':
-                    params_list.append(self)
-                else:
-                    # 依据参数名称，获取请求参数值
-                    argument_value = arguments.get(parameter_name)
-                    # 分以下几种情况，第一种情况 未取得请求参数
-                    if argument_value is None:
-                        # 查看是否有默认值，如果有直接跳过即可
-                        if parameter.default is not inspect.Parameter.empty:
-                            params_list.append(parameter.default)
-                            continue
-                        else:
-                            # 如果没有有默认值，要抛出异常 提示"请求缺少必要参数"
-                            raise BusinessException(StatusCode.REQUIRED_PARAM_IS_EMPTY(parameter_name))
-                    # 获取形参类型
-                    parameter_type = parameter.annotation
-                    # 形参类型为空，尝试获取形参默认值类型
-                    if parameter_type is inspect.Parameter.empty:
-                        # if parameter.default is inspect.Parameter.empty:
-                        #     parameter_type = type(parameter.default)
-                        # else:
-                        parameter_type = type(parameter.default)
-                    # # 获取实参类型
-                    # argument_type = type(argument_value)
-                    if isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
-                        # 仅一个 直接存入
-                        if len(argument_value) == 1:
-                            params_list.append(parse_val(argument_value[0], parameter_type))
-                        else:  # 多个要使用集合存入
-                            params_list.append([parse_val(v, parameter_type) for v in argument_value])
-                    else:
-                        params_list.append(parse_val(argument_value, parameter_type))
-            try:
-                # 判断是否为异步非阻塞方法，true 则直接调用
-                if inspect.iscoroutinefunction(handler_method):
-                    data = await handler_method(*params_list)
-                else:
-                    # 阻塞方法异步调用
-                    data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-                self.end_time = int(round(time.time() * 1000))
-                self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
-                if not self.original:
-                    self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
-            except Exception as e:
-                self.write(
-                    json.dumps(ResponseResult(data={"message": e.__str__()},
-                                              status_code=StatusCode.INTERNAL_SERVER_ERROR(e.__str__())),
-                               ensure_ascii=False, cls=JSONEncoder))
-        else:
-            raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
+        await self.request_handler()
 
     async def post(self):
         """
@@ -139,14 +76,16 @@ class BaseHandler(RequestHandler):
             # 获取当前请求的Content-Type
             content_type = self.request.headers.get('Content-Type')
             # 当前请求参数
-            arguments = self.request.arguments
-            body_arguments = self.request.body
-            if body_arguments:
-                body_arguments = body_arguments.decode()
-                if content_type.find(
-                        "multipart/form-data") == -1 and content_type != "application/x-www-form-urlencoded":
-                    body_arguments = json.loads(body_arguments)
-                    arguments.update(body_arguments)
+            arguments = {}
+            query_arguments = self.request.query_arguments
+
+            arguments.update(query_arguments)
+            if content_type == "application/json":
+                body_arguments = json.loads(self.request.body.decode())
+                arguments.update(body_arguments)
+            else:
+                body_arguments = self.request.body_arguments
+                arguments.update(body_arguments)
             # 获取处理方法的 参数签名
             signature = inspect.signature(handler_method)
             # parameterName 参数名称, parameter 参数对象
@@ -177,12 +116,15 @@ class BaseHandler(RequestHandler):
                     # # 获取实参类型
                     # argument_type = type(argument_value)
                     if isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
-                        # 仅一个 直接存入
-                        # if len(argument_value) == 1:
-                        #     params_list.append(parse_val(argument_value[0], parameter_type))
-                        # else:  # 多个要使用集合存入
-                        #     params_list.append([parse_val(v, parameter_type) for v in argument_value])
-                        params_list.append([parse_val(v, parameter_type) for v in argument_value])
+                        if self.request.method == "GET":
+                            if len(argument_value) == 1:
+                                # 仅一个 直接存入
+                                params_list.append(parse_val(argument_value[0], parameter_type))
+                            else:
+                                # 多个要使用集合存入
+                                params_list.append([parse_val(v, parameter_type) for v in argument_value])
+                        else:
+                            params_list.append([parse_val(v, parameter_type) for v in argument_value])
                     else:
                         params_list.append(parse_val(argument_value, parameter_type))
             try:
@@ -199,7 +141,9 @@ class BaseHandler(RequestHandler):
             except Exception as e:
                 self.write(
                     json.dumps(ResponseResult(data={"message": e.__str__()},
-                                              status_code=StatusCode.INTERNAL_SERVER_ERROR(e.__str__())),
+                                              status_code=e.status_code
+                                              if hasattr(e, "status_code") else StatusCode.INTERNAL_SERVER_ERROR(
+                                                  e.__str__())),
                                ensure_ascii=False, cls=JSONEncoder))
         else:
             raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
@@ -281,6 +225,8 @@ class JSONEncoder(json.JSONEncoder):
             return str(o, encoding="utf-8")
         elif isinstance(o, set):
             return list(o)
+        elif isinstance(o, Decimal):
+            return str(o)
         return json.JSONEncoder.default(self, o)
 
 
