@@ -16,15 +16,6 @@ from typing import Optional
 from lesscode.db.init_connection_pool import InitConnectionPool
 from lesscode.web.router_mapping import RouterMapping
 
-# project_name = project_path.split(os.path.sep)[-1]
-#
-# static_path = os.path.join(project_path, "static")
-# template_path = os.path.join(project_path, "templates")
-# temp_path = os.path.join(project_path, "temp")
-# sql_path = os.path.join(project_path, "sqls")
-# convert_path = os.path.join(project_path, "converters")
-# dataset_path = os.path.join(project_path, "dataset")
-
 define("application_name", default=f"{os.path.split(os.path.dirname(sys.argv[0]))[-1]}", type=str, help="配置文件")
 define("application_path", default=f"{os.path.dirname(sys.argv[0])}", type=str, help="应用运行根路径")
 # 生成秘钥方式 print(base64.b64encode(uuid.uuid4().bytes + uuid.uuid4().bytes).decode())
@@ -38,6 +29,11 @@ define("handler_path", default="handlers", type=str, help="处理器文件存储
 define("echo_sql", default=True, type=bool, help="是否启用SQL输出")
 define("async_enable", default=True, type=bool, help="是否启用异步")
 define("max_limit", default=500, type=int, help="单次查询最大数量")
+define("eureka_enable", default=False, type=bool, help="是否启用eureka")
+define("eureka_server", default="", type=str, help="eureka server地址")
+define("eureka_instance_name", default="", type=str, help="eureka实例名称，大写")
+define("eureka_instance_ip", default="", type=str, help="eureka实例ip或者域名")
+define("eureka_instance_port", default=8901, type=int, help="eureka实例ip或者域名")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -46,6 +42,11 @@ options.log_rotate_when = "D"
 # options.log_rotate_interval,
 options.log_file_num_backups = 30
 options.async_enable = True
+options.eureka_enable = False
+options.eureka_server = ""
+options.eureka_instance_name = ""
+options.eureka_instance_ip = ""
+options.eureka_instance_port = 8901
 
 
 class LogFormatter(TornadoLogFormatter):
@@ -120,6 +121,17 @@ class WebServer:
         self.server = tornado.httpserver.HTTPServer(self.app, max_buffer_size=500 * 1024 * 1024)  # 500M
 
     def start(self, num_processes: Optional[int] = 1, max_restarts: int = None):
+        if options.eureka_enable:
+            import py_eureka_client.eureka_client as eureka_client
+            eureka_server = options.eureka_server
+            eureka_instance_name = options.eureka_instance_name if options.eureka_instance_name \
+                else options.application_name
+            eureka_instance_ip = options.eureka_instance_ip if options.eureka_instance_ip else "127.0.0.1"
+            eureka_instance_port = options.eureka_instance_port if options.eureka_instance_port else options.port
+            eureka_client.init(eureka_server=eureka_server,
+                               app_name=eureka_instance_name,
+                               instance_ip=eureka_instance_ip,
+                               instance_port=eureka_instance_port)
         self.server.listen(options.port)
         self.server.start(num_processes, max_restarts)
         logging.info(f"start server : {options.application_name}")
